psychopy_ext.fmri.Analysis.extract_samples — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.fmri.Analysis.extract_samples

`Analysis.` `extract_samples`(subjid, runtype, ROIs, values='raw', offset=0)

  Produces a detrended dataset with info for classifiers.

  Args: | subjid (str) participant ID runtype (str) run type (useful if, for example, you also have localizer runs which you probably want to analyze separately from the experimental runs) ROIs (list) A pattern of ROI file patterns to be combined into one ROI
  Kwargs: | values (str, default: ‘raw’) What kind of values should be used. Usually you have ‘raw’, ‘beta’, and ‘t’. offset (int, default: 0) Offset to be applied to the signal (only used for ‘raw’ values).
  Returns: | ds (Dataset)